# About this theme in the example project

There are several ways to add themes to a project, including using submodules.
This theme is a copy of the lektor-theme-nix at ff71ea6cd2dd8ff83268891f9cdd60b344517064
and is not a repository or submodule. It is not intended to change often, and
is a simple copy to keep cloning lektor very simple - without someone having to
know how to manage submodules, or have to follow additional instruction steps
to populate the theme.
